==> tradebot-0.0.1.tar.gz: tradebot-0.0.1/setup.py <==

from distutils.core import setup
setup(
  name = 'tradebot',         # How you named your package folder
  packages = ['tradebot'],   # Chose the same as "name"
  version = '0.0.1',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'A wrapper around the TDAmeritrade REST API',   # Give a short description about your library
  author = 'Adeiron Barolli',                   # Type in your name
  author_email = 'obarolli@gmail.com',      # Type in your E-Mail
  url = 'https://github.com/abarolli/trade-bot',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/abarolli/trade-bot/archive/refs/tags/v0.0.1.tar.gz',
  keywords = ['stocks', 'statistics', 'rest api'],   # Keywords that define your package best
  install_requires=[  
          'request',
          'ruamel.yaml',
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
    'Programming Language :: Python :: 3.8',
    'Programming Language :: Python :: 3.9',
    'Programming Language :: Python :: 3.10',
  ],
)

==> tradebot-0.0.2.tar.gz: tradebot-0.0.2/setup.py <==

from distutils.core import setup
setup(
  name = 'tradebot',         # How you named your package folder
  packages = ['tradebot'],   # Chose the same as "name"
  version = '0.0.2',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'A wrapper around the TDAmeritrade REST API',   # Give a short description about your library
  author = 'Adeiron Barolli',                   # Type in your name
  author_email = 'obarolli@gmail.com',      # Type in your E-Mail
  url = 'https://github.com/abarolli/trade-bot',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/abarolli/trade-bot/archive/refs/tags/v0.0.2.tar.gz',
  keywords = ['stocks', 'statistics', 'rest api'],   # Keywords that define your package best
  install_requires=[  
          'requests',
          'ruamel.yaml',
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python :: 3.7', #Specify which python versions that you want to support
    'Programming Language :: Python :: 3.8',
    'Programming Language :: Python :: 3.9',
    'Programming Language :: Python :: 3.10',
  ],
)
